@@ -1,10 +1,8 @@
-# Copyright (c) 2008-2012 Simplistix Ltd
-# See license.txt for license details.
-
-from unittest import TestCase,TestSuite,makeSuite
+from unittest import TestCase
 
 from testfixtures import diff
 
+
 class TestDiff(TestCase):
 
     def test_example(self):
@@ -22,20 +20,20 @@ class TestDiff(TestCase):
 --- first
 +++ second
 @@ -1,5 +1,5 @@
- 
+
          line1
 -        line2
 +        line changed
          line3
          '''
         self.assertEqual(
-            expected,
-            actual,
-            '\n%r\n!=\n%r'%(expected,actual)
+            [line.strip() for line in expected.split("\n")],
+            [line.strip() for line in actual.split("\n")],
+            '\n%r\n!=\n%r' % (expected, actual)
             )
-        
+
     def test_no_newlines(self):
-        actual = diff('x','y')
+        actual = diff('x', 'y')
         # no rhyme or reason as to which of these comes back :-/
         try:
             expected = '@@ -1 +1 @@\n-x\n+y'
